# Metamodel schema


A metamodel for defining biolink related schemas

### Classes

 * [Element](Element.md) - a named element in the model
    * definition
       * class definition
       * slot definition
    * schema definition
    * subset definition
    * type definition
 * [Example](Example.md) - usage example and description
### Mixins

### Slots

 * [examples](examples.md) *subsets*: (owl) - example usages of an element
### Types

#### Built in

 * **Bool**
 * **NCName**
 * **URIorCURIE**
 * **XSDDate**
 * **XSDDateTime**
 * **XSDTime**
 * **float**
 * **int**
 * **str**
#### Defined

 * [String](String.md)  (**str**) 
